@@ -1,7 +1,7 @@
 /**sequencer_track_view.c is part of JamMo.
 License: GPLv2, read more from COPYING
 
-First call this: sequencer_sequencer_create_sequencer_container(JammoSequencer*)
+First call this: sequencer_track_view_tune_width
 And then sequencer_track_view_add_with_type(sequencerTrackViewTYpe)
  */
 #include <glib-object.h>
@@ -15,6 +15,7 @@ And then sequencer_track_view_add_with_type(sequencerTrackViewTYpe)
 #include "../../meam/jammo-editing-track.h"
 #include "../../meam/jammo-instrument-track.h"
 #include "../../meam/jammo-slider-track.h"
+#include "../../meam/jammo-backing-track.h"
 #include "../../meam/jammo-midi.h"
 #include "../../meam/jammo-meam.h" //JAMMO_DURATION_INVALID
 
@@ -22,28 +23,26 @@ And then sequencer_track_view_add_with_type(sequencerTrackViewTYpe)
 #include "../jammo-miditrack-view.h"
 #include "../jammo.h"
 #include "../jammo-cursor.h"
-
+#include "../save_helper.h"
 
 #include "sequencer_track_view.h"
 #include "sequencer.h"
 #include "midi_editor.h"
 #include "instrument_gui.h"
+#include "jammer_view.h"
+
+static int width_of_slot = 40;
+static gfloat track_height = 50.0;
+
 
 
 //We get these as parameters
 static int number_of_slots = -1;
-static int width_of_slot = -1;
-static guint64 duration_of_tracks = JAMMO_DURATION_INVALID; //they all must have same duration
-static gfloat track_height = -1;
 
 
-static ClutterActor* texture_of_cursor;
 static SequencerTrackView *track_views[6] = {NULL};
 static gint tracks_in_use = 0;
 
-static JammoSequencer* sequencer; // for playing the tracks;
-
-
 static gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer user_data);
 static gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer user_data);
 static gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpointer data);
@@ -55,7 +54,7 @@ TangleButton* last_pressed_volume_button = NULL;
  * Creates and returns SequencerTrackView struct
  */
 static SequencerTrackView *sequencer_track_view_new(ClutterActor *label,
-    ClutterActor *track_view, gint track_view_type, gboolean muted) {
+    ClutterActor *track_view, gint track_view_type, gboolean muted, gfloat current_volume) {
 
 	ClutterActor* mute_button = tangle_button_new_selectable_with_background_actors (
      clutter_texture_new_from_file("/opt/jammo/sequencer/button_mute.png", NULL), /* normal */
@@ -64,10 +63,30 @@ static SequencerTrackView *sequencer_track_view_new(ClutterActor *label,
 	clutter_actor_set_size(mute_button, track_height-4,track_height-4); //it is square. Four pixels marginal
 	tangle_button_set_selected(TANGLE_BUTTON(mute_button),muted);
 
-	ClutterActor* volume_button =  tangle_button_new_selectable_with_background_actors (
-     clutter_texture_new_from_file("/opt/jammo/sequencer/button_volume.png", NULL), /* normal */
-     clutter_texture_new_from_file("/opt/jammo/sequencer/button_volume_pressed.png", NULL),  /* interactive */
-     clutter_texture_new_from_file("/opt/jammo/sequencer/button_volume_pressed.png", NULL)); /* selected */
+	//Button for volume is dynamic texture.
+	//printf("current_volume : %f\n",current_volume);
+	gfloat height_ = 36; //background_heigt - nub_height
+	gfloat y = height_-current_volume*height_;
+	//printf("y : %f\n",y);
+
+	ClutterActor* dynamic_texture_for_button = tangle_widget_new();
+	ClutterActor* back = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_background.png",NULL);
+	ClutterActor* nub = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_button.png",NULL);
+	tangle_widget_set_background_actor(TANGLE_WIDGET(dynamic_texture_for_button), back);
+	tangle_widget_add(TANGLE_WIDGET(dynamic_texture_for_button), nub,NULL);
+	clutter_actor_set_y(nub,y);
+
+	ClutterActor* dynamic_texture_for_button_selected = tangle_widget_new();
+	ClutterActor* back_selected = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_background.png",NULL);
+	ClutterActor* nub_selected = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_button_selected.png",NULL);
+	tangle_widget_set_background_actor(TANGLE_WIDGET(dynamic_texture_for_button_selected), back_selected);
+	tangle_widget_add(TANGLE_WIDGET(dynamic_texture_for_button_selected), nub_selected,NULL);
+	clutter_actor_set_y(nub_selected,y);
+
+	ClutterActor* volume_button = tangle_button_new_selectable ();
+	tangle_button_set_normal_background_actor(TANGLE_BUTTON(volume_button),dynamic_texture_for_button);
+	tangle_button_set_selected_background_actor(TANGLE_BUTTON(volume_button),dynamic_texture_for_button_selected);
+
 
 	clutter_actor_set_size(volume_button, track_height-4,track_height-4); //it is square. Four pixels marginal
 
@@ -116,8 +135,7 @@ static void sequencer_track_view_add(SequencerTrackView *track_view) {
 
 	//Raise container's and scroller's height
 	clutter_actor_set_height(track_container,clutter_actor_get_height(track_container)+track_height);
-	ClutterActor* scrolling_actor = jammo_get_actor_by_id("fullsequencer-scroller-for-tracks");
-	clutter_actor_set_height(scrolling_actor, clutter_actor_get_height(track_container) + Y_OFFSET);
+	ClutterActor* texture_of_cursor = jammo_get_actor_by_id("fullsequencer_cursor_texture");
 	clutter_actor_set_height(texture_of_cursor, clutter_actor_get_height(track_container) + Y_OFFSET);
 
 	tracks_in_use++;
@@ -125,10 +143,11 @@ static void sequencer_track_view_add(SequencerTrackView *track_view) {
 
 
 //This contains lots of same rows than sequencer_track_view_add_with_type
-ClutterActor* sequencer_track_view_add_backing_track(JammoTrack* track, gboolean muted) {
+ClutterActor* sequencer_track_view_add_backing_track(JammoTrack* track, gboolean muted,gfloat volume) {
 	ClutterActor *label;
 	ClutterActor* track_view_actor = NULL; //This will be returned
 	SequencerTrackView *sequencer_track_view;
+	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 
 	gchar* name_of_label_button="";
 	name_of_label_button = "/opt/jammo/sequencer/label_backingtrack.png";
@@ -139,8 +158,9 @@ ClutterActor* sequencer_track_view_add_backing_track(JammoTrack* track, gboolean
 	track_view_actor = tangle_widget_new();
 	g_object_set_data (G_OBJECT(track_view_actor),"track",track);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(track));
-	sequencer_track_view = sequencer_track_view_new(label, track_view_actor, BACKING_TRACK_VIEW, muted);
+	sequencer_track_view = sequencer_track_view_new(label, track_view_actor, BACKING_TRACK_VIEW, muted,volume);
 	sequencer_track_view_add(sequencer_track_view);
+	printf("sequencer_track_view_add_backing_track over\n");
 	return track_view_actor;
 }
 
@@ -149,8 +169,11 @@ ClutterActor* sequencer_track_view_add_backing_track(JammoTrack* track, gboolean
  * Returns track_view_actor (jammo_track_view) of newly created sequencer_track_view
  * Returns NULL is askes invalid type.
  */
-ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean muted, gint optional_parameter) {
+ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean muted, gfloat volume, gint optional_parameter) {
 	gint twt = track_view_type;
+	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+	guint64 duration_of_tracks = jammo_sequencer_get_duration(sequencer);
+
 	printf("Making '%d' track (duration: %" G_GUINT64_FORMAT ")\n",track_view_type, duration_of_tracks);
 
 	guint64 duration_of_one_slot = duration_of_tracks / number_of_slots;
@@ -180,13 +203,13 @@ ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean
 			break;
 
 		case EDITING_TRACK_VIEW:
-			if (optional_parameter==RHYTHM_TRACK)
+			if (optional_parameter==JAMMO_SAMPLE_RHYTMICAL)
 				name_of_label_button = "/opt/jammo/sequencer/label_loop_rhythm.png";
-			else if (optional_parameter==HARMONY_TRACK)
+			else if (optional_parameter==JAMMO_SAMPLE_HARMONICAL)
 				name_of_label_button = "/opt/jammo/sequencer/label_loop_harmony.png";
-			else if (optional_parameter==MELODY_TRACK)
+			else if (optional_parameter==JAMMO_SAMPLE_MELODICAL)
 				name_of_label_button = "/opt/jammo/sequencer/label_loop_melody.png";
-			else if (optional_parameter==EFFECT_TRACK)
+			else if (optional_parameter==JAMMO_SAMPLE_EFFECT)
 				name_of_label_button = "/opt/jammo/sequencer/label_loop_effect.png";
 			else //Same sane default value
 				name_of_label_button = "/opt/jammo/sequencer/label_loop_effect.png";
@@ -216,7 +239,10 @@ ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean
 
 		//TODO: we need to know highest_note and lowest_note for this instrument!
 		track_view_actor = jammo_miditrack_view_new(JAMMO_INSTRUMENT_TRACK(track),
-          number_of_slots, duration_of_one_slot, width_of_slot, track_height,60,24); //height can be anything, we zoom it
+          number_of_slots*4,       //Miditrack-view uses more narrow slots
+          duration_of_one_slot/4,
+          width_of_slot, track_height, //height can be anything, we zoom it
+          59,36);  //Highest-note and lowest-note. TODO: should be asked from instrumet
 		jammo_miditrack_view_zoom_to_fit(JAMMO_MIDITRACK_VIEW(track_view_actor), number_of_slots*width_of_slot,track_height);
 		jammo_miditrack_view_set_show_grid(JAMMO_MIDITRACK_VIEW(track_view_actor),FALSE);
 		}
@@ -241,12 +267,13 @@ ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean
 
 		track_view_actor = jammo_track_view_new(JAMMO_EDITING_TRACK(track),
           number_of_slots, duration_of_one_slot, width_of_slot, track_height);
-		g_object_set(track_view_actor, "line-every-nth-slot", 1, NULL);
+		clutter_actor_set_reactive(track_view_actor, TRUE);
+		g_object_set(track_view_actor, "line-every-nth-slot", 1, "sample-type", optional_parameter, NULL);
 	}
-	
+
 
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(track));
-	sequencer_track_view = sequencer_track_view_new(label, track_view_actor, twt, muted);
+	sequencer_track_view = sequencer_track_view_new(label, track_view_actor, twt, muted,volume);
 	sequencer_track_view_add(sequencer_track_view);
 	return track_view_actor;
 }
@@ -268,7 +295,7 @@ static gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton
 		//TODO: some way to go straight to editor.
 
 		//jamming
-		instrument_gui_start(JAMMO_MIDITRACK_VIEW(s_track_view->track_view),sequencer, NULL); //NULL means no slider
+		instrument_gui_start(JAMMO_MIDITRACK_VIEW(s_track_view->track_view), NULL); //NULL means no slider
 
 		//editor
 		//midi_editor_start_with_miditrack_view(JAMMO_MIDITRACK_VIEW(track->track_view));
@@ -280,10 +307,18 @@ static gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton
 		JammoTrack* track= JAMMO_TRACK(g_object_get_data(G_OBJECT(container),"track"));
 		if (JAMMO_IS_SLIDER_TRACK(track)) {
 			printf(" it is slider_track\n");
-			instrument_gui_start(NULL,sequencer, container); //NULL means no keyboard, but slider
+			instrument_gui_start(NULL, container); //NULL means no keyboard, but slider
+		}
+		else if (JAMMO_IS_BACKING_TRACK(track)){
+			printf(" it is backing_track\n");
+			clutter_actor_show(jammo_get_actor_by_id("backingtrack-selection-view"));
+			clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-view"));
 		}
 		else {
-			printf(" it is backing_track\n");
+			printf(" it is editing_track (start jammer)\n");
+			clutter_actor_show(jammo_get_actor_by_id("jammer-view"));
+			clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-view"));
+			start_jammer();
 		}
 	}
 
@@ -303,11 +338,15 @@ static gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpoin
 	SequencerTrackView *track_view = (SequencerTrackView*) data;
 	JammoPlayingTrack* jammotrack;
 
-	//slider track is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
-	if (TANGLE_IS_WIDGET(track_view->track_view))
-		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view->track_view),"track"));
-	else
+	//slider and backingtrack is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
+	if (JAMMO_IS_TRACK_VIEW(track_view->track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view->track_view)) {
 		g_object_get(track_view->track_view, "track", &jammotrack, NULL);
+	} else if (TANGLE_IS_WIDGET(track_view->track_view)) {
+		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view->track_view),"track"));
+	} else  {
+		return FALSE;
+	}
+
 
 	jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(jammotrack), tangle_button_get_selected(tanglebutton));
 
@@ -319,17 +358,36 @@ static gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpoin
 /**
 This syncs scrollers offset to tracks volume.
 */
-gboolean sequencer_volumebar_used (ClutterActor *volume_scroller, gpointer none){
-	//-80 is height of the visible marker.
-	gfloat height = clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-80;
-	gfloat offset;
-	g_object_get(volume_scroller, "scrolling-offset-y", &offset,NULL);
-	//printf("height %f, offset :%f, ratio %f\n",height, offset,offset/height);
+gboolean sequencer_volumebar_used (ClutterActor *scroll_action, gpointer none){
+	printf("sequencer_volumebar_used\n");
+	if (!last_pressed_volume_button)
+		return FALSE;
+
+	ClutterActor* volume_scroller = clutter_actor_meta_get_actor(CLUTTER_ACTOR_META(scroll_action));
+	//-50 is height of the visible marker.
+	gfloat height = clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-50;
+	gfloat offset,not_used;
+	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(scroll_action), &not_used,&offset);
+
+	printf("height %f, offset :%f\n",height, offset);
 
 	JammoPlayingTrack* jammotrack = g_object_get_data(G_OBJECT(volume_scroller),"track");
 
-	jammo_playing_track_set_volume(jammotrack,offset/height);
-	//printf("new volume:%f\n",offset/height);
+	gfloat new_volume = offset/height; //This is between [0...1]
+	jammo_playing_track_set_volume(jammotrack,new_volume);
+	//printf("new volume:%f\n\n",new_volume);
+
+	ClutterActor* container = tangle_button_get_normal_background_actor(last_pressed_volume_button);
+	ClutterActor* nub = tangle_widget_get_nth_child(TANGLE_WIDGET(container),0);
+
+	ClutterActor* container2 = tangle_button_get_selected_background_actor(last_pressed_volume_button);
+	ClutterActor* nub2 = tangle_widget_get_nth_child(TANGLE_WIDGET(container2),0);
+
+	gfloat height_ = 36; //clutter_actor_get_height(container) - clutter_actor_get_height(nub); //If hided. container reports it's height wrongly
+	//printf("height_: %f\n",height_);
+
+	clutter_actor_set_y(nub,height_-new_volume*height_);
+	clutter_actor_set_y(nub2,height_-new_volume*height_);
 	return FALSE;
 }
 
@@ -343,13 +401,18 @@ static gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpo
 
 	ClutterActor* volume_container = jammo_get_actor_by_id("fullsequencer-volumebar-container");
 	ClutterActor* volume_scroller = jammo_get_actor_by_id("fullsequencer-volumebar-scroller");
+	ClutterAction* scroll_action = tangle_actor_get_action_by_type(volume_scroller,TANGLE_TYPE_SCROLL_ACTION);
+
 	JammoPlayingTrack* jammotrack;
 
-	//slider track is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
-	if (TANGLE_IS_WIDGET(track_view->track_view))
-		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view->track_view),"track"));
-	else
+	//slider and backingtrack is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
+	if (JAMMO_IS_TRACK_VIEW(track_view->track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view->track_view)) {
 		g_object_get(track_view->track_view, "track", &jammotrack, NULL);
+	} else if (TANGLE_IS_WIDGET(track_view->track_view)) {
+		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view->track_view),"track"));
+	} else  {
+		return FALSE;
+	}
 
 	gfloat current_volume = jammo_playing_track_get_volume(jammotrack);
 	//printf("volume of this track is :%f\n",current_volume);
@@ -367,7 +430,7 @@ static gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpo
 		//-50 is height of the visible marker.
 		gfloat new_place = (clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-50)*current_volume;
 		//printf("new place: %f\n",new_place);
-		clutter_actor_animate(CLUTTER_ACTOR(volume_scroller), CLUTTER_EASE_IN_OUT_QUAD, 250, "scrolling-offset-y", new_place, NULL);
+		tangle_object_animate(G_OBJECT(scroll_action),  CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-y", new_place, NULL);
 		g_object_set_data(G_OBJECT(volume_scroller),"track",jammotrack);
 		if (last_pressed_volume_button)
 			tangle_button_set_selected(last_pressed_volume_button,FALSE);
@@ -379,75 +442,33 @@ static gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpo
 
 
 
-bool save_sequencer_state(gchar* outputFilename) {
-#ifdef migrating
-	printf("Saving composition\n");
-	FILE *ofp;
-
-	ofp = fopen(outputFilename, "w");
-	g_free(outputFilename);
-	g_return_val_if_fail(ofp != NULL, FALSE);
-
-	GList* children;
-	TangleWidget* widget;
-	JammoSampleButton *jsb;
-
-	int i;
-
-	for(i = 0; i < tracks_in_use; i++) {
-		fprintf(ofp, "Track-type: %s\n", track_views[i]->track_type);
-		if(strcmp(track_views[i]->track_type, "KEYBOARD_TRACK_VIEW") == 0)
-		{
-		//TODO
-			continue;
-		}
-		printf("%s\n", track_views[i]->track_type);
-
-		widget = TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(track_views[i]->track_view)));
-
-		for (children = tangle_widget_get_children_readonly(widget); children; children = children->next) {
-
-			jsb = JAMMO_SAMPLE_BUTTON(children->data);
-			//printf("x: '%lf' \n",clutter_actor_get_x(CLUTTER_ACTOR(jsb)));
-			printf("slot: '%d' \n", (gint) clutter_actor_get_x(CLUTTER_ACTOR(jsb))/width_of_slot);
-			fprintf(ofp,"%d\n", (gint) clutter_actor_get_x(CLUTTER_ACTOR(jsb))/width_of_slot);
-			gchar* sound;
-			gchar* image;
-			g_object_get(jsb, "sample-filename", &sound, NULL);
-			g_object_get(jsb, "image-filename", &image, NULL);
-			printf("sound: '%s' \n",sound);
-			printf("image: '%s'\n", image);
-			fprintf(ofp,"%s\n",sound);
-			fprintf(ofp,"%s\n",image);
-		}
-	}
-
-	fclose(ofp);
-#endif
-	return FALSE;
-}
 
 //JSON callback
 void fullsequencer_on_cursor_notify_x(GObject* object, GParamSpec* param_spec, gpointer user_data) {
 	//printf("fullsequencer_on_cursor_notify_x\n");
 
-	TangleScrollingActor* scrolling_actor = TANGLE_SCROLLING_ACTOR(jammo_get_actor_by_id("fullsequencer-scroller-for-tracks"));
+	ClutterActor* scrolling_view = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
+	ClutterAction* scroll_action = tangle_actor_get_action_by_type(scrolling_view,TANGLE_TYPE_SCROLL_ACTION);
+
 	gfloat x, visible, offset, max;
 
 	g_object_get(object, "x", &x, NULL);
-	g_object_get(scrolling_actor, "width", &visible, "scrolling-offset-x", &offset, "scrolling-width", &max, NULL);
+	g_object_get(scrolling_view, "width", &visible, NULL);
+	g_object_get(scroll_action, "offset-x", &offset, "max-offset-x", &max, NULL);
+	//printf("x=%f, visible-width =%f, offset=%f, max=%f\n",x,visible,offset,max);
+
 	if (x < offset) {
 		offset = x - visible + 80.0;
 		if (offset < 0.0) {
 			offset = 0.0;
 		}
-		clutter_actor_animate(CLUTTER_ACTOR(scrolling_actor), CLUTTER_EASE_IN_OUT_QUAD, 250, "scrolling-offset-x", offset, NULL);
+		tangle_object_animate(G_OBJECT(scroll_action),  CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-x", offset, NULL);
 	} else if (x > offset + visible - 80.0) {
 		offset += 160.0;
 		if (offset > max) {
 			offset = max;
 		}
-		clutter_actor_animate(CLUTTER_ACTOR(scrolling_actor), CLUTTER_EASE_IN_OUT_QUAD, 250, "scrolling-offset-x", offset, NULL);
+		tangle_object_animate(G_OBJECT(scroll_action),  CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-x", offset, NULL);
 	}
 }
 
@@ -464,6 +485,7 @@ void fullsequencer_play_clicked (TangleButton* tanglebutton, gpointer none){
 	gboolean selected;
 	g_object_get(tanglebutton, "selected", &selected,  NULL);
 
+	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	if (selected) {
 		jammo_sequencer_play(sequencer);
 	}
@@ -486,53 +508,47 @@ void fullsequencer_community_clicked (TangleButton* tanglebutton, gpointer none)
 }
 
 void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
-	printf("fullsequencer: Home pressed Doesn't do anything\n");
+	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 
-	clutter_main_quit();
-
-	/*
 	jammo_sequencer_stop(sequencer);
-	save_sequencer_state();
-	leave_sequencer();
 
-	*/
+	gchar* meta_data = g_strdup_printf
+	("\"pitch\" : \"%s\",\n\"tempo\" : %d,\n",jammo_sequencer_get_pitch(sequencer),jammo_sequencer_get_tempo(sequencer));
+
+	save_composition("7-12/", jammo_get_actor_by_id("fullsequencer-container-for-tracks"),meta_data);
+	g_free(meta_data);
+	clutter_actor_show(jammo_get_actor_by_id("startmenu-view"));
 }
 
 
-
 /*
-Will make container (TangleWidget) and put it inside scroller.
 Also prepare cursor.
 */
-void sequencer_track_view_create_area_for_tracks(JammoSequencer* seq, guint n_slots, guint64 total_duration, gfloat slot_width, gfloat height) {
-	//Set statics
-	sequencer = seq;
+void sequencer_track_view_tune_width() {
+	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+	guint64 duration;
+	duration = jammo_sequencer_get_duration(sequencer);
+
+	g_print("Duration: %" G_GUINT64_FORMAT "\n", duration);
+
+	gint tempo_factory = 4;
+	//We want operate whole time with guint64.
+	guint64 temp=60*tempo_factory;
+	guint64 one_second = 1000000000L;
+	guint64 big = temp * one_second;
+	guint64 duration_of_one_slot = big / jammo_sequencer_get_tempo(sequencer);
+
+	gint n_slots = duration/duration_of_one_slot;
+	printf("*number_of_slots (in backing-track / for editing-track): %d\n",n_slots);
+
+
+	//Set static
 	number_of_slots = n_slots;
-	duration_of_tracks = total_duration;
-	width_of_slot = (int)slot_width;
-	track_height =  height; //track_height is slot_height
-
-
-	gfloat width_of_area = number_of_slots*width_of_slot;
-
-
-	ClutterActor* track_container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
-	//Tune width of track_container
-	//Height will be 0 and when track is added it will be raised
-	clutter_actor_set_size(track_container,width_of_area, 0.0);
-
-
-	ClutterActor* scrolling_actor = jammo_get_actor_by_id("fullsequencer-scroller-for-tracks");
-
-	//tune X-position of scroller
-	gfloat x_place_scroller=194.0; //TODO //width_of: label+mute_button+volume_slider
-	clutter_actor_set_x(scrolling_actor, x_place_scroller );
-	//Height will be 0 and when track is added it will be raised
-	clutter_actor_set_size(scrolling_actor, 800-x_place_scroller, 0.0);
 
 	//CURSOR
-	texture_of_cursor = jammo_get_actor_by_id("fullsequencer_cursor_texture"); //We want change height of this
+	gfloat width_of_area = number_of_slots*width_of_slot;
 	ClutterActor* cursor;
 	cursor = jammo_get_actor_by_id("fullsequencer_cursor");
 	clutter_actor_set_size(cursor, width_of_area, 80.0); //width is important, height is not used
 }
+
