@@ -2,13 +2,16 @@
 #include <stdlib.h>
 #include <glib.h>
 
+#include "../configure.h"
 
 FILE *ink_F;
 
 void create_ink_head()
 {
 
-  ink_F = fopen("/tmp/jammo/motion_inkml.xml", "w");
+  gchar* filename = g_strdup_printf("%s/motion_inkml.xml", JAMMO_DIRECTORY);
+  ink_F = fopen(filename, "w");
+  g_free(filename);
   if(ink_F ==NULL) {
     g_print("Cannot open file..\n");
     exit(EXIT_FAILURE);
